@@ -404,9 +404,9 @@ def download_subcommand(
     directory, eg:
 
     \b
-    dest-path/English/All_Disciplines/package_name/title.fmt
-    dest-path/German/All_Disciplines/package_name/title.fmt
-    dest-path/German/Emergency_Nursing/package_name/title.fmt
+    - dest-path/English/All_Disciplines/package_name/title.fmt
+    - dest-path/German/All_Disciplines/package_name/title.fmt
+    - dest-path/German/Emergency_Nursing/package_name/title.fmt
 
     The `package` and `packages` subcommands will also save downloaded
     files into directories with package names rooted in the destination
